Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(566)

Unified Diff: webrtc/p2p/base/p2ptransportchannel.cc

Issue 1868353004: Update prflx candidates' generation when setting ICE credentials. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Re-enable the disabled test condition. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/p2p/base/p2ptransportchannel.cc
diff --git a/webrtc/p2p/base/p2ptransportchannel.cc b/webrtc/p2p/base/p2ptransportchannel.cc
index 66532411b29f5241c6b0f163d87c91d7ba9cbe2a..8fb33e58cb99934351c1f4c14de77f3dec0d1509 100644
--- a/webrtc/p2p/base/p2ptransportchannel.cc
+++ b/webrtc/p2p/base/p2ptransportchannel.cc
@@ -390,10 +390,13 @@ void P2PTransportChannel::SetRemoteIceCredentials(const std::string& ice_ufrag,
candidate.set_password(ice_pwd);
}
}
// We need to update the credentials for any peer reflexive candidates.
for (Connection* conn : connections_) {
- conn->MaybeSetRemoteIceCredentials(ice_ufrag, ice_pwd);
+ conn->MaybeSetRemoteIceCredentialsAndGeneration(remote_ice_parameters_);
honghaiz3 2016/04/18 16:12:37 Why does this need to pass all ice parameters and
Taylor Brandstetter 2016/04/18 23:30:01 You're right. I don't remember what I was thinking
}
+ // Updating the remote ICE candidate generation could change the sort order.
+ RequestSort();
}
void P2PTransportChannel::SetRemoteIceMode(IceMode mode) {
@@ -390,10 +390,13 @@ void P2PTransportChannel::SetRemoteIceCredentials(const std::string& ice_ufrag,
}
}
- // We need to update the credentials for any peer reflexive candidates.
+ // We need to update the credentials and generation for any peer reflexive
+ // candidates.
for (Connection* conn : connections_) {

Powered by Google App Engine
This is Rietveld 408576698